@@ -5,10 +5,13 @@ const Name = "murex"
 
 // Version number of $SHELL
 // Format of version string should be "(major).(minor).(revision) DESCRIPTION"
-const Version = "2.8.2100 BETA"
+const Version = "2.9.5000"
 
 // Copyright is the copyright owner string
 const Copyright = "© 2018-2022 Laurence Morgan"
 
 // License is the projects software license
-const License = "Licence GPL v2"
+const License = "License GPL v2"
+
+// ShellModule is the name of the module that REPL code gets imported into
+var ShellModule = Name + "/shell"
