@@ -12,6 +12,7 @@ func init() {
 		">>":                    "Writes STDIN to disk - appending contents if file already exists",
 		">":                     "Writes STDIN to disk - overwriting contents if file already exists",
 		"@[":                    "Outputs a ranged subset of data from STDIN",
+		"autoglob":              "Command prefix to expand globbing",
 		"[[":                    "Outputs an element from a nested structure",
 		"[":                     "Outputs an element from an array, map or table",
 		"a":                     "A sophisticated yet simple way to build an array or list",
@@ -68,6 +69,7 @@ func init() {
 		"left":                  "Left substring every item in a list",
 		"let":                   "Evaluate a mathematical function and assign to variable",
 		"lockfile":              "Create and manage lock files",
+		"man-get-flags":         "Parses man page files for command line flags",
 		"man-summary":           "Outputs a man page summary of a command",
 		"map":                   "Creates a map from two data sources",
 		"match":                 "Match an exact value in an array",
@@ -96,6 +98,7 @@ func init() {
 		"read":                  "`read` a line of input from the user and store as a variable",
 		"regexp":                "Regexp tools for arrays / lists of strings",
 		"right":                 "Right substring every item in a list",
+		"runmode":               "Alter the scheduler's behaviour at higher scoping level",
 		"runtime":               "Returns runtime information on the internal state of _murex_",
 		"rx":                    "Regexp pattern matching for file system objects (eg '.*\\.txt')",
 		"set":                   "Define a local variable and set it's value",
@@ -104,8 +107,6 @@ func init() {
 		"suffix":                "Prefix a string to every item in a list",
 		"summary":               "Defines a summary help text for a command",
 		"switch":                "Blocks of cascading conditionals",
-		"swivel-datatype":       "Converts tabulated data into a map of values for serialised data-types such as JSON and YAML",
-		"swivel-table":          "Rotates a table by 90 degrees",
 		"ta":                    "A sophisticated yet simple way to build an array of a user defined data-type",
 		"tabulate":              "Table transformation tools",
 		"test":                  "_murex_'s test framework - define tests, run tests and debug shell scripts",
@@ -118,6 +119,13 @@ func init() {
 		"trypipe":               "Checks state of each function in a pipeline and exits block on error",
 		"version":               "Get _murex_ version",
 		"while":                 "Loop until condition false",
+
+		"base64": "Encode or decode a base64 string",
+		"!bz2":   "Decompress a bz2 file",
+		"gz":     "Compress or decompress a gzip file",
+		"qr":     "Creates a QR code from STDIN",
+		"select": "Inlining SQL into shell pipelines",
+		"sleep":  "Suspends the shell for a number of seconds",
 	}
 
 	Synonym = map[string]string{
@@ -135,9 +143,13 @@ func init() {
 		">":                     ">",
 		"fwrite":                ">",
 		"@[":                    "@[",
+		"range":                 "@[",
+		"autoglob":              "autoglob",
 		"[[":                    "[[",
+		"element":               "[[",
 		"[":                     "[",
 		"![":                    "[",
+		"index":                 "[",
 		"a":                     "a",
 		"addheading":            "addheading",
 		"alias":                 "alias",
@@ -208,6 +220,7 @@ func init() {
 		"left":                  "left",
 		"let":                   "let",
 		"lockfile":              "lockfile",
+		"man-get-flags":         "man-get-flags",
 		"man-summary":           "man-summary",
 		"map":                   "map",
 		"match":                 "match",
@@ -242,6 +255,7 @@ func init() {
 		"regexp":                "regexp",
 		"!regexp":               "regexp",
 		"right":                 "right",
+		"runmode":               "runmode",
 		"runtime":               "runtime",
 		"builtins":              "runtime",
 		"rx":                    "rx",
@@ -255,8 +269,6 @@ func init() {
 		"summary":               "summary",
 		"!summary":              "summary",
 		"switch":                "switch",
-		"swivel-datatype":       "swivel-datatype",
-		"swivel-table":          "swivel-table",
 		"ta":                    "ta",
 		"tabulate":              "tabulate",
 		"test":                  "test",
@@ -271,5 +283,14 @@ func init() {
 		"version":               "version",
 		"while":                 "while",
 		"!while":                "while",
+
+		"base64":  "base64",
+		"!base64": "base64",
+		"!bz2":    "!bz2",
+		"gz":      "gz",
+		"!gz":     "gz",
+		"qr":      "qr",
+		"select":  "select",
+		"sleep":   "sleep",
 	}
 }
