@@ -4,6 +4,7 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/lmorg/murex/config"
 	"github.com/lmorg/murex/config/defaults"
 	"github.com/lmorg/murex/test/count"
 )
@@ -18,3 +19,14 @@ func TestDefaultProfileNotEmpty(t *testing.T) {
 	}
 
 }
+
+func TestDefaultConfigLoads(t *testing.T) {
+	count.Tests(t, 1)
+
+	c := config.InitConf
+	defaults.Defaults(c, false)
+
+	if len(c.DumpConfig()) == 0 {
+		t.Errorf("config not loading")
+	}
+}
