@@ -1,6 +1,7 @@
 package lang
 
 import (
+	"fmt"
 	"path/filepath"
 	"strings"
 )
@@ -34,6 +35,9 @@ func autoGlob(p *Process) error {
 			if err != nil {
 				return err
 			}
+			if len(globbed) == 0 {
+				return fmt.Errorf("no files match '%s'", old[i])
+			}
 			new = append(new, globbed...)
 		} else {
 			new = append(new, old[i])
