@@ -34,6 +34,11 @@ func TestParamHangBug(t *testing.T) {
 			Block:  `out: $FOO[BAR]`,
 			Stdout: "\n",
 		},
+		{
+			Block: `out: $FOO[[BAR]]`,
+			Stdout: "\n",
+			Stderr: "Error in `[[` ( 4,9): murex doesn't know how to lookup `[][]string` (please file a bug with on the murex Github page: https://lmorg/murex)\n",
+		},
 		{
 			Block:  `out: $ FOO[BAR]`,
 			Stdout: "$ FOO[BAR]\n",
@@ -75,6 +80,10 @@ func TestParamHangBug(t *testing.T) {
 			Block:  `out: @FOO[BAR]`,
 			Stdout: "\n",
 		},
+		{
+			Block:  `out: @FOO[[BAR]]`,
+			Stdout: "\n",
+		},
 		{
 			Block:  `out: @ FOO[BAR]`,
 			Stdout: "@ FOO[BAR]\n",
