@@ -1,25 +1,26 @@
-package parser
+	package parser
 
 //go:generate stringer -type=PipeToken
 
 import (
 	"regexp"
 
-	"github.com/lmorg/murex/utils/ansi"
+	"github.com/lmorg/murex/utils/ansi/codes"
 )
 
 // syntax highlighting
 var (
-	hlFunction    = ansi.Bold
-	hlVariable    = ansi.FgRed
-	hlEscaped     = ansi.FgYellow
-	hlSingleQuote = ansi.FgBlue
-	hlDoubleQuote = ansi.FgBlue
-	hlBraceQuote  = ansi.FgBlue
-	hlBlock       = ansi.Bold
-	hlPipe        = ansi.FgMagenta
-	hlComment     = ansi.FgGreen
-	hlError       = ansi.BgRed
+	hlFunction    = codes.Bold //+ codes.FgGreen
+	hlVariable    = codes.FgGreen
+	hlEscaped     = codes.FgYellow
+	hlSingleQuote = codes.FgBlue
+	hlDoubleQuote = codes.FgBlue
+	hlBraceQuote  = codes.FgBlue
+	hlBlock       = []string{codes.FgGreen, codes.FgMagenta, codes.FgBlue, codes.FgYellow}
+	hlPipe        = codes.FgMagenta
+	hlComment     = codes.FgGreen + codes.Invert
+	hlError       = codes.FgRed + codes.Invert
+	hlRedirect    = codes.FgGreen
 
 	rxAllowedVarChars = regexp.MustCompile(`^[_a-zA-Z0-9]$`)
 )
@@ -39,6 +40,7 @@ type ParsedTokens struct {
 	QuoteBrace    int
 	NestedBlock   int
 	SquareBracket bool
+	AngledBracket bool
 	ExpectFunc    bool
 	ExpectParam   bool
 	pop           *string
@@ -61,12 +63,13 @@ const (
 	PipeTokenArrow                     // `->` (murex style pipe)
 	PipeTokenGeneric                   // `=>` (reformat to generic)
 	PipeTokenRedirect                  // `?`  (STDERR redirected to STDOUT and vice versa)
+	PipeTokenAppend                    // `>>` (append STDOUT to a file)
 )
 
 // Parse a single line of code and return the tokens for a selected command
 func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 	var readFunc bool
-	reset := []string{ansi.Reset, hlFunction}
+	reset := []string{codes.Reset, hlFunction}
 	syntaxHighlighted = hlFunction
 	pt.Loc = -1
 	pt.ExpectFunc = true
@@ -84,9 +87,9 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 			reset = reset[:len(reset)-1]
 		}
 		syntaxHighlighted += string(r) + reset[len(reset)-1]
-		if len(reset) == 1 && pt.NestedBlock > 0 {
-			syntaxHighlighted += hlBlock
-		}
+		/*if len(reset) == 1 && pt.NestedBlock > 0 {
+			syntaxHighlighted += hlBlock[pt.NestedBlock%len(hlBlock)]
+		}*/
 	}
 
 	ansiResetNoChar := func() {
@@ -94,16 +97,16 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 			reset = reset[:len(reset)-1]
 		}
 		syntaxHighlighted += reset[len(reset)-1]
-		if len(reset) == 1 && pt.NestedBlock > 0 {
-			syntaxHighlighted += hlBlock
-		}
+		/*if len(reset) == 1 && pt.NestedBlock > 0 {
+			syntaxHighlighted += hlBlock[pt.NestedBlock%len(hlBlock)]
+		}*/
 	}
 
 	ansiChar := func(colour string, r ...rune) {
 		syntaxHighlighted += colour + string(r) + reset[len(reset)-1]
-		if len(reset) == 1 && pt.NestedBlock > 0 {
-			syntaxHighlighted += hlBlock
-		}
+		/*if len(reset) == 1 && pt.NestedBlock > 0 {
+			syntaxHighlighted += hlBlock[pt.NestedBlock%len(hlBlock)]
+		}*/
 	}
 
 	var i int
@@ -157,7 +160,7 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 				fallthrough
 			default:
 				pt.Comment = true
-				syntaxHighlighted += hlComment + string(block[i:]) + ansi.Reset
+				syntaxHighlighted += hlComment + string(block[i:]) + codes.Reset
 				//return
 				defer func() { pt.CommentMsg = string(pt.commentMsg) }()
 			}
@@ -300,26 +303,26 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 			}
 
 		case '=':
-		switch {
-		case pt.Escaped:
-			escaped()
-		case pt.QuoteSingle, pt.QuoteDouble, pt.QuoteBrace > 0, readFunc:
-			*pt.pop += `=`
-			syntaxHighlighted += string(block[i])
-		case pt.ExpectFunc:
-			pt.Loc = i
-			syntaxHighlighted += string(block[i])
-		default:
-			pt.Loc = i
-			syntaxHighlighted += string(block[i])
-			pt.ExpectParam = true
-		}
+			switch {
+			case pt.Escaped:
+				escaped()
+			case pt.QuoteSingle, pt.QuoteDouble, pt.QuoteBrace > 0, readFunc:
+				*pt.pop += `=`
+				syntaxHighlighted += string(block[i])
+			case pt.ExpectFunc:
+				pt.Loc = i
+				syntaxHighlighted += string(block[i])
+			default:
+				pt.Loc = i
+				syntaxHighlighted += string(block[i])
+				pt.ExpectParam = true
+			}
 
 		case ':':
 			switch {
 			case pt.Escaped:
 				escaped()
-			case pt.QuoteSingle, pt.QuoteDouble, pt.QuoteBrace > 0:
+			case pt.QuoteSingle, pt.QuoteDouble, pt.QuoteBrace > 0, pt.SquareBracket:
 				*pt.pop += `:`
 				syntaxHighlighted += string(block[i])
 			case !pt.ExpectFunc:
@@ -358,7 +361,7 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 					pt.PipeToken = PipeTokenGeneric
 				}
 				pt.pop = &pt.FuncName
-				//pt.FuncName = ""
+				//pt.Unsafe = true
 				pt.LastFuncName = pt.FuncName
 				pt.Parameters = make([]string, 0)
 				syntaxHighlighted = syntaxHighlighted[:len(syntaxHighlighted)-1]
@@ -366,13 +369,37 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 				ansiColour(hlPipe, block[i-1])
 				ansiReset('>')
 				syntaxHighlighted += hlFunction
+			case i > 0 && (block[i-1] == '\t' || block[i-1] == ' ') && next('>'):
+				if pos != 0 && pt.Loc >= pos {
+					return
+				}
+				i++
+				pt.Loc = i
+				pt.LastFlowToken = i - 1
+				pt.Unsafe = true
+				pt.ExpectFunc = false
+				readFunc = false
+				pt.ExpectParam = true
+				pt.SquareBracket = false
+				pt.PipeToken = PipeTokenAppend
+				pt.FuncName = ">>"
+				pt.Parameters = make([]string, 0)
+				ansiColour(hlPipe, '>')
+				ansiReset('>')
+				syntaxHighlighted += hlRedirect
 			case pt.ExpectFunc, readFunc:
 				readFunc = true
 				*pt.pop += `>`
-				fallthrough
+				pt.Loc = i
+				syntaxHighlighted += ">"
+			case pt.AngledBracket:
+				*pt.pop += `>`
+				pt.Loc = i
+				syntaxHighlighted += ">" + codes.Reset
+
 			default:
 				pt.Loc = i
-				syntaxHighlighted += string(block[i])
+				syntaxHighlighted += ">"
 			}
 
 		case '|':
@@ -396,21 +423,28 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 				pt.LastFuncName = pt.FuncName
 				pt.Parameters = make([]string, 0)
 				if next('>') {
-					readFunc = true
 					*pt.pop += `>`
-					pt.Loc = i
+					pt.LastFlowToken = i - 1
+					pt.Unsafe = true
+					pt.ExpectFunc = false
+					readFunc = false
+					pt.ExpectParam = true
+					pt.SquareBracket = false
 					i++
 					if next('>') {
 						pt.Loc = i
 						i++
 						ansiChar(hlPipe, '|', '>', '>')
+						pt.PipeToken = PipeTokenAppend
 					} else {
 						ansiChar(hlPipe, '|', '>')
 					}
+
+					syntaxHighlighted += hlRedirect
 				} else {
 					ansiChar(hlPipe, block[i])
+					syntaxHighlighted += hlFunction
 				}
-				syntaxHighlighted += hlFunction
 			}
 
 		case '&':
@@ -496,7 +530,7 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 			case pt.Escaped:
 				escaped()
 			case pt.QuoteSingle, pt.QuoteDouble, pt.QuoteBrace > 0:
-				*pt.pop += `?`
+				*pt.pop += "?"
 				syntaxHighlighted += string(block[i])
 			case i > 0 && block[i-1] == ' ':
 				if pos != 0 && pt.Loc >= pos {
@@ -515,7 +549,7 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 				syntaxHighlighted += hlFunction
 			default:
 				*pt.pop += `?`
-				syntaxHighlighted += string(block[i])
+				syntaxHighlighted += "?"
 			}
 
 		case '{':
@@ -532,8 +566,12 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 				pt.PipeToken = PipeTokenNone
 				pt.pop = &pt.FuncName
 				pt.Parameters = make([]string, 0)
-				//pt.Unsafe = true
-				syntaxHighlighted += hlBlock + string(block[i])
+				if pt.NestedBlock >= 0 {
+					i := pt.NestedBlock % len(hlBlock)
+					syntaxHighlighted += hlBlock[i] + "{" + codes.Reset + hlFunction
+				} else {
+					syntaxHighlighted += hlError + "{" //+ codes.Reset
+				}
 			}
 
 		case '}':
@@ -542,13 +580,17 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 				escaped()
 			case pt.QuoteSingle, pt.QuoteDouble, pt.QuoteBrace > 0:
 				*pt.pop += `}`
-				syntaxHighlighted += string(block[i])
+				syntaxHighlighted += "}"
 			default:
+				if pt.NestedBlock >= 1 {
+					i := pt.NestedBlock % len(hlBlock)
+					syntaxHighlighted += hlBlock[i] + "}" + codes.Reset
+				} else {
+					syntaxHighlighted += hlError + "}" //+ codes.Reset
+				}
 				pt.NestedBlock--
-				//pt.Unsafe = true
-				syntaxHighlighted += string(block[i])
 				if pt.NestedBlock == 0 {
-					syntaxHighlighted += ansi.Reset + reset[len(reset)-1]
+					syntaxHighlighted += reset[len(reset)-1]
 				}
 			}
 
@@ -630,16 +672,17 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 			case pt.Escaped:
 				escaped()
 			case readFunc:
-				*pt.pop += string(block[i])
-				syntaxHighlighted += string(block[i])
+				*pt.pop += "<"
+				syntaxHighlighted += "<"
 			case pt.ExpectFunc:
-				*pt.pop = string(block[i])
+				*pt.pop = "<"
 				readFunc = true
-				syntaxHighlighted += string(block[i])
+				syntaxHighlighted += "<"
 			default:
 				pt.Unsafe = true
-				*pt.pop += string(block[i])
-				syntaxHighlighted += string(block[i])
+				*pt.pop += "<"
+				syntaxHighlighted += hlRedirect + "<"
+				pt.AngledBracket = true
 			}
 
 		default:
@@ -678,17 +721,6 @@ func Parse(block []rune, pos int) (pt ParsedTokens, syntaxHighlighted string) {
 	}
 	pt.Loc++
 	pt.VarLoc++
-	syntaxHighlighted += ansi.Reset
+	syntaxHighlighted += codes.Reset
 	return
 }
-
-/*func Highlight(block []rune) (hl string) {
-	ast, _ := lang.ParseBlock(block)
-
-	for i := range *ast {
-		ast[i].Name
-	}
-
-	return
-}
-*/
